pub enum BayerDepth {
Depth8,
Depth16BE,
Depth16LE,
}Expand description
The depth and endianness of the raw image.
Note that many cameras only capture 12-bits per pixel, but still store the data as 16-bits per pixel. These should be treated as 16-bits per pixel for the purposes of this library.
Variants